#!/usr/bin/python
from __future__ import annotations


ANSIBLE_METADATA = {'metadata_version': '1.1',
                    'status': ['stableinterface'],
                    'supported_by': 'core'}

DOCUMENTATION = """
---
module: action1
short_description: Action Test module
description:
    - Action Test module
author:
    - Ansible Core Team
"""

EXAMPLES = """
"""

RETURN = """
"""
